@@ -309,22 +309,6 @@ class Connection:
         return f"Connection({self.__dict__})"
 
 
-class CreateConnection:
-
-    def __init__(self, name, connection_type_id, analytics_pipeline_id, properties, description=None):
-        self.name = name
-        self.connectionTypeId = connection_type_id
-        self.analyticsPipelineId = analytics_pipeline_id
-        self.properties = properties
-        self.description = description
-
-    def __eq__(self, other):
-        return self.name == other.name
-
-    def __repr__(self):
-        return f"CreateConnection({self.__dict__})"
-
-
 class ConnectionCheckStatus(Enum):
     SUCCESS = 1
     FAILURE = 2
