@@ -129,7 +129,7 @@ class PipelineRun:
     def __init__(self, pipelineId, versionId=None, status=PipelineRunStatus.STARTED, id=None, startedAt=None,
                  finishedAt=None, result=PipelineRunResult.UNKNOWN, client=None, args=None,
                  continuationId=None, successEvents=None, errorEvents=None, warningEvents=None, avgExecutionTime=None,
-                 **kwrgs):
+                 *argumentss, **kwargs):
         """
         Description:
                 Pipeline run used for instantiate run of the pipeline. To create new pipeline run you need to pass pipelineId, version.
@@ -234,6 +234,9 @@ class PipelineRun:
         )
         if associatedJobUids is None:
             associatedJobUids = []
+        elif not isinstance(associatedJobUids, list):
+            raise Exception('associatedJobUids should be a list')
+
         payload = self._convert_span_to_dict(create_span, associatedJobUids)
         res = self.client.create_span(self.id, payload)
         span_context = SpanContext(client=self.client, span=res, context_data= context_data, new_span = True)
@@ -246,7 +249,7 @@ class PipelineRun:
         :param span_uid: uid of the span
         :return: SpanContext instance of the input span uid
         """
-        span = self.client.get_span( pipeline_run_id= self.id,uid= span_uid)
+        span = self.client.get_span(pipeline_run_id= self.id, uid=span_uid)
         span_context = SpanContext(client=self.client, span= span)
         return span_context
 
@@ -311,7 +314,7 @@ class Node:
                  uid = None,
                  createdVia: NodeAddition = NodeAddition.PIPELINE_CREATION,
                  status: NodeStatus = NodeStatus.ACTIVE,
-                 parentId = None
+                 parentId = None, *args, **kwargs
                  ):
         self.id = id
         self.type = type
@@ -349,7 +352,7 @@ class Edge:
                  toId = None,
                  fromAssetType: NodeType = None,
                  toAssetType: NodeType = None,
-                 versionId = None
+                 versionId = None, *args, **kwargs
                  ):
         self.id = id
         self.fromId = fromId
@@ -379,7 +382,7 @@ class Pipeline:
                  context=None,
                  client=None,
                  tags=None,
-                 **kwrgs):
+                 *args, **kwargs):
         """
         Description:
             Class of the pipeline
@@ -521,7 +524,7 @@ class PipelineInfo:
     pipeline: Pipeline = None
     runs: List[PipelineRun] = list()
 
-    def __init__(self, pipeline=None, runs=None):
+    def __init__(self, pipeline=None, runs=None, *args, **kwargs):
         if isinstance(pipeline, dict):
             self.pipeline = Pipeline(**pipeline)
         else:
@@ -544,7 +547,7 @@ class PipelineDetails:
     nodes: List[Node] = list()
     edges: List[Edge] = list()
 
-    def __init__(self, pipeline=None, nodes=None, edges=None):
+    def __init__(self, pipeline=None, nodes=None, edges=None, *args, **kwargs):
         if isinstance(pipeline, dict):
             self.pipeline = Pipeline(**pipeline)
         else:
