@@ -1,39 +1,65 @@
 from acceldata_sdk.errors import TorchSdkException
 from acceldata_sdk.models.pipeline import CreatePipeline, Pipeline, PipelineRun
 from acceldata_sdk.torch_http_client import TorchHttpClient
-from acceldata_sdk.models.datasource import CreateDataSource
-from acceldata_sdk.constants import RuleExecutionStatus, FailureStrategy, PolicyType, AssetSourceType
+from acceldata_sdk.constants import RuleExecutionStatus, FailureStrategy, PolicyType, AssetSourceType, \
+    SDK_MIN_VERSION_SUPPORT, SdkSupportedVersions
+
 from acceldata_sdk.models.rule import RuleResource
 from typing import List
+import distutils
+from semantic_version import Version, SimpleSpec
+import logging
 from acceldata_sdk.models.ruleExecutionResult import RuleResult, PolicyFilter, RuleType
 
 
 class TorchClient:
+    logger = logging.getLogger('torch')
+    logger.setLevel(logging.INFO)
+
     """
             Description : Torch user client is used to send data to catalog server.
-
             :param url: (String) url of the catalog server
             :param timeout_ms: (Integer) timeout of the requests sending to catalog
             :param access_key: (String) Access key of API key. You can generate API key from torch UI's setting
             :param secret_key: (String) Secret key of API key.
-
+            :param do_version_check: (bool) Enable version compatibility check between sdk and torch.
             Ex.  TorchClient = TorchUserClient(url='https://torch.acceldata.local:5443', access_key='OY2VVIN2N6LJ', secret_key='da6bDBimQfXSMsyyhlPVJJfk7Zc2gs')
     """
 
-    def __init__(self, url, timeout_ms=10000, access_key: str = None, secret_key: str = None):
+    def __init__(self, url, timeout_ms=10000, access_key: str = None, secret_key: str = None,
+                 do_version_check: bool = True):
         """
                 Description : Torch user client is used to send data to catalog server.
-
                 :param url: (String) url of the catalog server
                 :param timeout_ms: (Integer) timeout of the requests sending to catalog
                 :param access_key: (String) Access key of API key. You can generate API key from torch UI's setting
                 :param secret_key: (String) Secret key of API key.
-
+                :param do_version_check: (bool) Enable version compatibility check between sdk and torch.
                 Ex.  TorchClient = TorchUserClient(url='https://torch.acceldata.local:5443', access_key='OY2VVIN2N6LJ', secret_key='da6bDBimQfXSMsyyhlPVJJfk7Zc2gs')
         """
         if access_key is None and secret_key is None:
             raise Exception('Access key and secret key - required')
         self.client = TorchHttpClient(url=url, access_key=access_key, secret_key=secret_key, timeout_ms=timeout_ms)
+        if isinstance(do_version_check, str):
+            self.do_version_check = bool(distutils.util.strtobool(do_version_check))
+        else:
+            self.do_version_check = do_version_check
+        if self.do_version_check:
+            supported_versions = self.get_supported_sdk_versions()
+            ver_comparator = SimpleSpec(f'>={supported_versions.minVersion},<={supported_versions.maxVersion}')
+            if Version(SDK_MIN_VERSION_SUPPORT) not in ver_comparator:
+                raise Exception(f'Torch supports sdk versions between {supported_versions.minVersion} and '
+                                f'{supported_versions.maxVersion}')
+        else:
+            self.logger.info('Skipping version check')
+
+    def get_supported_sdk_versions(self) -> SdkSupportedVersions:
+        """
+        Description:
+            To get supported sdk versions
+        :return: (SdkSupportedVersions) newly created SdkSupportedVersions class instance
+        """
+        return self.client.get_supported_sdk_versions()
 
     def create_pipeline(self, pipeline: CreatePipeline) -> Pipeline:
         """
@@ -90,15 +116,6 @@ class TorchClient:
         """
         return self.client.get_pipeline_runs(pipeline_id)
 
-    def create_datasource(self, datasource: CreateDataSource):
-        """
-        Description:
-            To create datasource in torch catalog
-        :param datasource: (CreateDataSource) class instance of the datasource to be created
-        :return: (DataSource) newly created datasource
-        """
-        return self.client.create_datasource(datasource)
-
     def get_datasource(self, assembly_identifier, properties=False):
         """
         Description:
@@ -191,51 +208,9 @@ class TorchClient:
     def get_tags(self):
         return self.client.get_tags()
 
-    def delete_tag(self, tag: str):
-        return self.client.delete_tag(tag)
-
-    def update_data_protection(self, tag: str, is_protected: bool):
-        return self.client.update_data_protection(tag, is_protected)
-
-    def discover(self):
-        # add filters in discover api & more details in asset class
-        return self.client.discover()
-
-    def list_all_snapshots(self):
-        return self.client.list_all_snapshots()
-
-    def get_user(self, user_id=None, username=None):
-        if user_id is None and username is None:
-            raise TorchSdkException('Either provide uid or id to find an asset')
-        if user_id is not None:
-            return self.client.get_user_by_id(id=user_id)
-        if username is not None:
-            return self.client.get_user_by_name(username=username)
-
-    def create_api_key(self):
-        return self.client.create_api_keys()
-
-    def get_api_keys(self):
-        return self.client.get_api_keys()
-
-    def delete_api_key(self, access_key: str):
-        return self.client.delete_api_key(access_key)
-
-    def get_notifications(self):
-        return self.client.get_notifications()
-
-    def get_incidents(self):
-        return self.client.get_incidents()
-
-    def list_all_analysis_pipelines(self):
-        return self.client.list_all_analysis_pipelines()
-
     def get_analysis_pipeline(self, id: int):
         return self.client.get_analysis_pipeline(id)
 
-    def get_all_auto_profile_configurations(self):
-        return self.client.get_all_auto_profile_configurations()
-
     def get_asset(self, identifier):
         """"
             Description:
@@ -280,57 +255,12 @@ class TorchClient:
         return self.client.get_all_rules(filter=filter, page=page, size=size, sortBy=sortBy,
                                          withLatestExecution=withLatestExecution)
 
-    def list_all_classification_configurations(self):
-        return self.client.list_all_classification_configurations()
-
-    def create_classification_configuration(self, classification_config):
-        return self.client.create_classification_configuration(classification_config)
-
-    def update_classification_configuration(self, classification_config):
-        return self.client.update_classification_configuration(classification_config)
-
-    def get_classification_configuration(self, name: str):
-        return self.client.get_classification_configuration(name)
-
-    def delete_classification_configuration(self, name: str):
-        return self.client.delete_classification_configuration(name)
-
-    def list_setting_groups(self):
-        return self.client.list_setting_groups()
-
-    def find_settings_by_group(self, setting_group_name: str):
-        return self.client.find_settings_by_group(setting_group_name)
-
-    def get_setting(self, key: str):
-        return self.client.get_setting(key)
-
-    def update_setting_value(self, key: str, value: str):
-        return self.client.update_setting_value(key, value)
-
-    def reset_setting_value(self, key:str):
-        return self.client.reset_setting_value(key)
-
-    def list_all_connections(self):
-        return self.client.list_all_connections()
-
     def create_connection(self, create_connection):
         return self.client.create_connection(create_connection)
 
-    def update_connection(self, update_connection):
-        if update_connection.name is None:
-            raise TorchSdkException('Update connection should have name of the connection. (update_connection : '
-                                    'CreateConnection class instance)')
-        return self.client.update_connection(update_connection.name, update_connection)
-
-    def delete_connection(self, id):
-        return self.client.delete_connection(id)
-
     def check_connection(self, connection):
         return self.client.check_connection(connection)
 
-    def get_connection(self, name):
-        return self.client.get_connection(name)
-
     def execute_dq_rule(self, rule_id, incremental=False):
         return self.client.execute_dq_rule(rule_id, incremental)
 
@@ -358,7 +288,7 @@ class TorchClient:
     def get_dq_rule_result(self, execution_id) -> RuleResult:
         return self.client.get_dq_rule_result(execution_id)
 
-    def execute_policy(self, policy_type: PolicyType, policy_id, sync=True, incremental=False, failure_strategy: FailureStrategy = FailureStrategy.DoNotFail):
+    def execute_policy(self, policy_type: PolicyType, policy_id, sync=True, incremental=False, failure_strategy: FailureStrategy = FailureStrategy.DoNotFail, pipeline_run_id=None):
         """
         Description:
             To execute policies synchronously and asynchronously
@@ -369,7 +299,7 @@ class TorchClient:
         :param failure_strategy: (enum) optional Set it to decide if it should fail at error,
             fail at warning or never fail
         """
-        return self.client.execute_rule(policy_type, policy_id, sync, incremental, failure_strategy)
+        return self.client.execute_rule(policy_type, policy_id, sync, incremental, failure_strategy, pipeline_run_id)
 
     def get_policy_status(self, policy_type, execution_id) -> RuleExecutionStatus:
         """
@@ -392,14 +322,14 @@ class TorchClient:
         """
         return self.client.get_rule_execution_result(policy_type, execution_id, failure_strategy)
 
-    def policy_executions(self, identifier, rule_type: RuleType, page=0, size=25, sortBy='finishedAt:DESC'):
+    def policy_executions(self, identifier, policy_type: RuleType, page=0, size=25, sortBy='finishedAt:DESC'):
         """
         Description:
             To list rule executions
         :param identifier: id or name of executed rule
-        :param rule_type: (Enum RuleType) Type of executed rule
+        :param policy_type: (Enum RuleType) Type of executed rule
         :param page: (Int) page number of query output
         :param size: (Int) Size of each page
         :param sortBy: (Str) sorting order
         """
-        return self.client.policy_executions(identifier, rule_type, page, size, sortBy)
+        return self.client.policy_executions(identifier, policy_type, page, size, sortBy)
