@@ -6,26 +6,22 @@ from typing import List
 import requests
 
 from acceldata_sdk.models.connection import ConnectionType, AnalyticsPipeline, Connection, ConnectionCheck, ConnectionCheckStatus
-from acceldata_sdk.models.notifications import Notification, Incident
-from acceldata_sdk.models.profile import AutoProfileConfiguration, Profile, ProfileRequest
+from acceldata_sdk.models.profile import Profile, ProfileRequest
 from acceldata_sdk.models.rule import Rule, RuleCancelResponse, RuleExecution, ExecutionResult
-from acceldata_sdk.models.setting import SettingGroup, Setting
-from acceldata_sdk.models.tags import TAG, Watch, AssetTag, AssetActivity, AssetComment, AssetLabel, User, APIKeys, \
-    ClassificationConfig
+from acceldata_sdk.models.tags import TAG, AssetTag, AssetLabel
 from acceldata_sdk.errors import APIError, TorchSdkException
 from acceldata_sdk.models.assetType import AssetType
-from acceldata_sdk.models.datasource import CreateDataSource, DataSource,SourceType, CrawlerStatus, RootAsset
+from acceldata_sdk.models.datasource import DataSource,SourceType, CrawlerStatus
 from acceldata_sdk.models.job import Job
 from acceldata_sdk.models.pipeline import CreatePipeline, Pipeline, PipelineRun, PipelineInfo, PipelineDetails
-from acceldata_sdk.models.snapshot import SnapshotData
 from acceldata_sdk.models.span import Span, SpanContextEvent, CreateSpanEvent
 from acceldata_sdk.client import TorchClientInterFace
-from acceldata_sdk.models.asset import Asset, AssetRelation, ChildAsset, Metadata
+from acceldata_sdk.models.asset import Asset, Metadata
 from requests_toolbelt import MultipartEncoder
 from acceldata_sdk.models.dqrule import DataQualityExecutionResult, DataQualityRule, DataQualityRuleResource
 from acceldata_sdk.models.reconcillationrule import ReconcillationExecutionResult, ReconciliationRuleResource
 from acceldata_sdk.models.ruleExecutionResult import RuleResult, PolicyFilter, ExecutionPeriod, RuleType, RuleExecutionSummary
-from acceldata_sdk.constants import AssetSourceType
+from acceldata_sdk.constants import AssetSourceType, SdkSupportedVersions
 from acceldata_sdk.common import Executor
 from acceldata_sdk.constants import PolicyType, FailureStrategy, RuleExecutionStatus
 
@@ -95,6 +91,12 @@ class TorchHttpClient(TorchClientInterFace, ABC):
             pipeline_dict['meta'] = meta
         return pipeline_dict
 
+    def get_supported_sdk_versions(self) -> SdkSupportedVersions:
+        response = self._get(
+            f'{self._catalog_api_base}/sdk/compatible-versions'
+        )
+        return SdkSupportedVersions(**response['versions'])
+
     # function to create pipeline
     def create_pipeline(self, pipeline: CreatePipeline) -> Pipeline:
         """
@@ -173,60 +175,6 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         self.logger.info('Pipeline Job Created')
         return Job(**response['node'])
 
-    # convert datasource to dict data type
-    def _convert_datasource_to_dict(self, datasource: CreateDataSource):
-        """
-            Description:
-                Convert CreateDataSource class instance to dict type
-            :param datasource: CreateDataSource class instance
-            :return: dict form of CreateDataSource class instance
-        """
-        payload = datasource.__dict__
-        source_type = asdict(datasource.sourceType)
-        payload['sourceType'] = source_type
-        datasource_payload = {}
-        if not datasource.isVirtual:
-            config_prop = []
-            for cp in datasource.configProperties:
-                config_prop.append(asdict(cp))
-            payload['properties'] = config_prop
-        payload.pop('configProperties')
-        datasource_payload['assembly'] = payload
-
-        return datasource_payload
-
-    # create datasource in torch
-    def create_datasource(self, datasource: CreateDataSource) -> DataSource:
-        """
-        Description:
-            used to create datasource
-        :param datasource: createDatasource class instance that you want to create
-        :return: created datasource instance
-        """
-        payload = self._convert_datasource_to_dict(datasource)
-        response = self._post(
-            f'{self._catalog_api_base}/assemblies',
-            payload=payload
-        )
-        response['data']['client'] = self
-        return DataSource(**response['data'])
-
-    def update_datasource(self, datasource_id: int, datasource: CreateDataSource) -> DataSource:
-        """
-        Description:
-            used to update datasource
-        :param datasource_id: id of the datasource to be updated
-        :param datasource: createDatasource class instance that you want to create
-        :return: created datasource instance
-        """
-        payload = self._convert_datasource_to_dict(datasource)
-        response = self._put(
-            f'{self._catalog_api_base}/assemblies/{datasource_id}',
-            payload=payload
-        )
-        response['data']['client'] = self
-        return DataSource(**response['data'])
-
     def delete_datasource(self, datasource_id: int):
         """
         Description:
@@ -239,31 +187,6 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         )
         return response
 
-    def get_root_asset(self, datasource_id):
-        response = self._get(
-            f'{self._catalog_api_base}/assemblies/{datasource_id}/rootAssets'
-        )
-        root_assets = list(response)
-        root_assets_list = []
-        for res in root_assets:
-            root_assets_list.append(RootAsset(**res))
-        return root_assets_list
-
-    # to create asset for any given datasource
-    def create_asset(self, asset: {}) -> Asset:
-        """
-        Description:
-            Used to create asset in a datasource
-        :param asset: (dict) asset input
-        :return: Asset class instance of created asset
-        """
-        response = self._put(
-            f'{self._catalog_api_base}/assets',
-            payload=asset
-        )
-        response['data']['client'] = self
-        return Asset(**response['data'])
-
     def start_crawler(self, datasource_name) -> CrawlerStatus:
         response = self._post(
             f'{self._catalog_api_base}/crawler/{datasource_name}',
@@ -271,86 +194,12 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         )
         return CrawlerStatus(**response['data'])
 
-    def restart_crawler(self, datasource_name) -> CrawlerStatus:
-        response = self._post(
-            f'{self._catalog_api_base}/crawler/{datasource_name}/restart',
-            payload={}
-        )
-        return CrawlerStatus(**response['data'])
-
-    def remove_crawler(self, datasource_name) -> CrawlerStatus:
-        response = self._delete(
-            f'{self._catalog_api_base}/crawler/{datasource_name}/restart'
-        )
-        return CrawlerStatus(**response['data'])
-
     def get_crawler_status(self, datasource_name) -> CrawlerStatus:
         response = self._get(
             f'{self._catalog_api_base}/crawler/{datasource_name}',
         )
         return CrawlerStatus(**response['data'])
 
-    # initialise new version of snapshot for a datasource
-    def initialise_snapshot(self, snapshot_data: {}) -> SnapshotData:
-        """
-        Description:
-            Used to initialise new version of snapshot for a datasource
-        :param snapshotData: dict of snapshotData class instance
-        :return: created snapshotData class instance
-        """
-        response = self._post(
-            f'{self._catalog_api_base}/snapshots/initialise',
-            payload=snapshot_data
-        )
-        return SnapshotData(**response['data'])
-
-    # get current version of datasource
-    def get_current_snapshot(self, datasource_id: int) -> SnapshotData:
-        """
-        Description:
-            If you want to get current version of a datasource
-        :param datasourceId: id of a datasource
-        :return: SnapshotData class instance of datasource
-        """
-        response = self._get(
-            f'{self._catalog_api_base}/snapshots/{datasource_id}/version'
-        )
-        return SnapshotData(**response)
-
-    def list_datasource_snapshots(self, id: int):
-        response = self._get(
-            f'{self._catalog_api_base}/snapshots/{id}'
-        )
-        snapshots = list(response)
-        snapshots_list = []
-        for res in snapshots:
-            snapshots_list.append(SnapshotData(**res))
-        return snapshots_list
-
-    def list_all_snapshots(self):
-        response = self._get(
-            f'{self._catalog_api_base}/snapshots'
-        )
-        snapshots = list(response)
-        snapshots_list = []
-        for res in snapshots:
-            snapshots_list.append(SnapshotData(**res))
-        return snapshots_list
-
-    # create relation between asset
-    def create_asset_relation(self, asset_relation: {}) -> AssetRelation:
-        """
-        Description:
-            used to create relation between any 2 existing assets
-        :param asset_relation: relation dict object
-        :return: created AssetRelation class instance
-        """
-        response = self._put(
-            f'{self._catalog_api_base}/asset-relations',
-            payload=asset_relation
-        )
-        return AssetRelation(**response['data'])
-
     # create run for a pipeline
     def create_pipeline_run(self, pipeline_run: {}) -> PipelineRun:
         """
@@ -595,54 +444,6 @@ class TorchHttpClient(TorchClientInterFace, ABC):
             tags_list.append(TAG(**res))
         return tags_list
 
-    def delete_tag(self, tag):
-        tags = self.get_tags()
-        tag_id = None
-        for tg in tags:
-            if tg.name == tag:
-                tag_id = tg.id
-        if tag_id is None:
-            raise TorchSdkException(f'Tag not found with name {tag}')
-        response = self._delete(
-            url=f'{self._catalog_api_base}/tag/{tag_id}'
-        )
-        return response
-
-    def update_data_protection(self, tag: str, is_protected: bool):
-        payload = {
-            'isProtected': is_protected
-        }
-        tags = self.get_tags()
-        tag_id = None
-        for tg in tags:
-            if tg.name == tag:
-                tag_id = tg.id
-        if tag_id is None:
-            raise TorchSdkException(f'Tag not found with name {tag}')
-        response = self._put(
-            url=f'{self._catalog_api_base}/tags/{tag_id}',
-            payload=payload
-        )
-        return response
-
-    def discover(self):
-        url = f'{self._catalog_api_base}/assets/discover?page=0&size=25'
-        response = self._get(url)
-        datasource = list(response['data']['assemblies'])
-        ds_list = []
-        for res in datasource:
-            ds_list.append(DataSource(**res))
-
-        assets = list(response['data']['assets'])
-        assets_list = []
-        for res in assets:
-            assets_list.append(Asset(**res))
-        response = {
-            'datasources': ds_list,
-            'assets': assets_list
-        }
-        return response
-
     def get_datasource(self, assembly_identifier, properties: bool = False) -> DataSource:
         """
         Description:
@@ -742,12 +543,6 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         )
         return response
 
-    def delete_asset(self, id: int):
-        response = self._delete(
-            url=f'{self._catalog_api_base}/assets/{id}'
-        )
-        return response
-
     def get_asset_metadata(self, id: int):
         url = f'{self._catalog_api_base}/assets/{id}/metadata'
         response = self._get(
@@ -756,15 +551,6 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         metadata = Metadata(**response['data'])
         return metadata
 
-    def update_asset_metadata(self, id: int, metadata: dict):
-        url = f'{self._catalog_api_base}/assets/{id}/metadata'
-        response = self._put(
-            url=url,
-            payload=metadata
-        )
-        metadata = Metadata(**response['data'])
-        return metadata
-
     def add_custom_metadata(self, id: int, custom_metadata: dict):
         url = f'{self._catalog_api_base}/assets/{id}/metadata/custom'
         response = self._post(
@@ -784,16 +570,6 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         profile_response = Profile(**response['data'])
         return profile_response
 
-    def auto_tag_asset(self, id: int, payload: dict):
-        url = f'{self._catalog_api_base}/assets/{id}/autotag'
-        response = self._post(
-            url=url,
-            payload=payload
-        )
-        response['data']['client'] = self
-        profile_response = Profile(**response['data'])
-        return profile_response
-
     def sample_data(self, id: int):
         url = f'{self._catalog_api_base}/assets/{id}/sample'
         response = self._get(
@@ -825,51 +601,6 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         )
         return response['result']
 
-    def get_related_assets(self, id: int):
-        if id is None:
-            raise Exception('Asset id is required')
-        url = f'{self._catalog_api_base}/assets/{id}/relatedAssets'
-        response = self._get(
-            url=url
-        )
-        relations = list(response['relations'])
-        relations_list = []
-        for res in relations:
-            relations_list.append(AssetRelation(**res))
-        return relations_list
-
-    def get_child_assets(self, id: int):
-        if id is None:
-            raise Exception('Asset id is required')
-        url = f'{self._catalog_api_base}/assets/{id}/childAssets'
-        response = self._get(
-            url=url
-        )
-        child_assets = list(response['childAssets'])
-        child_assets_list = []
-        for res in child_assets:
-            child_assets_list.append(ChildAsset(**res))
-        return child_assets_list
-
-    def start_watch(self, id: int):
-        if id is None:
-            raise Exception('Asset id is required')
-        url = f'{self._catalog_api_base}/assets/{id}/watch'
-        response = self._post(
-            url=url
-        )
-        start_watch = Watch(**response['data'])
-        return start_watch
-
-    def stop_watch(self, id: int):
-        if id is None:
-            raise Exception('Asset id is required')
-        url = f'{self._catalog_api_base}/assets/{id}/watch'
-        response = self._delete(
-            url=url
-        )
-        return response
-
     def get_asset_tags(self, id: int):
         if id is None:
             raise Exception('Asset id is required')
@@ -892,15 +623,6 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         )
         return AssetTag(**response)
 
-    def remove_asset_tag(self, id: int, tag_id: int):
-        if id is None:
-            raise Exception('Asset id is required')
-        url = f'{self._catalog_api_base}/assets/{id}/removeTag/{tag_id}'
-        response = self._delete(
-            url=url
-        )
-        return response
-
     def add_asset_labels(self, id: int, payload: dict):
         if id is None:
             raise Exception('Asset id is required')
@@ -927,204 +649,12 @@ class TorchHttpClient(TorchClientInterFace, ABC):
             labels_list.append(AssetLabel(**lbl))
         return labels_list
 
-    def list_all_classification_configurations(self):
-        url = f'{self._catalog_api_base}/classification-configs?sortBy=name:ASC&page=0&size=50'
-        response = self._get(
-            url=url
-        )
-        configs = list(response['classificationConfigs'])
-        configs_list = []
-        for res in configs:
-            configs_list.append(ClassificationConfig(**res))
-        return configs_list
-
-    def get_classification_configuration(self, name: str):
-        url = f'{self._catalog_api_base}/classification-configs?sortBy=name:ASC&page=0&size=50'
-        response = self._get(
-            url=url
-        )
-        configs = list(response['classificationConfigs'])
-        config_requested = None
-        for res in configs:
-            config = ClassificationConfig(**res)
-            if config.name == name:
-                config_requested = config
-        if config_requested is None:
-            raise TorchSdkException(f'Classification not found with {name}.')
-        return config_requested
-
-    def delete_classification_configuration(self, name: str):
-        config = self.get_classification_configuration(name)
-        if config is not None:
-            response = self._delete(
-                url=f'{self._catalog_api_base}/classification-configs/{config.id}'
-            )
-            return response
-        else:
-            raise TorchSdkException(f'Error deleting config. Classification config not found with {name}.')
-
-    def create_classification_configuration(self, classification_config):
-        url = f'{self._catalog_api_base}/classification-configs'
-        payload = {
-            'classificationConfig': classification_config.__dict__
-        }
-        response = self._post(
-            url=url,
-            payload=payload
-        )
-        return ClassificationConfig(**response)
-
-    def update_classification_configuration(self, classification_config):
-        if classification_config.id is None:
-            raise TorchSdkException(f'Classification id is required to update it.  {classification_config.name}')
-        url = f'{self._catalog_api_base}/classification-configs'
-        payload = {
-            'classificationConfig': classification_config.__dict__
-        }
-        response = self._put(
-            url=url,
-            payload=payload
-        )
-        return ClassificationConfig(**response)
-
-    def list_setting_groups(self):
-        url = f'{self._catalog_api_base}/settinggroups'
-        response = self._get(
-            url=url
-        )
-        settings = list(response)
-        settings_list = []
-        for res in settings:
-            settings_list.append(SettingGroup(**res))
-        return settings_list
-
-    def find_settings_by_group(self, setting_group_name):
-        group_id = None
-        setting_group_list = self.list_setting_groups()
-        for setting in setting_group_list:
-            if setting.name == setting_group_name:
-                group_id = setting.id
-        if group_id is None:
-            raise TorchSdkException(f'Setting group not found with name {setting_group_name}')
-
-        url = f'{self._catalog_api_base}/settinggroups/{group_id}'
-        response = self._get(
-            url=url
-        )
-        settings = list(response['settings'])
-        settings_list = []
-        for res in settings:
-            settings_list.append(Setting(**res['setting']))
-        return settings_list
-
-    def get_setting(self, key: str):
-        if key is None:
-            raise Exception('Setting key is required.')
-        url = f'{self._catalog_api_base}/setting/{key}'
-        response = self._get(
-            url=url
-        )
-        return Setting(**response)
-
-    def update_setting_value(self, key: str, value: str):
-        setting = self.get_setting(key)
-        if setting is None:
-            raise TorchSdkException(f'Setting not found with name {key}')
-        payload = {
-            "settingValue": str(value)
-        }
-        url = f'{self._catalog_api_base}/setting/{setting.id}'
-        response = self._put(
-            url=url, payload=payload
-        )
-        return response
-
-    def reset_setting_value(self, key: str):
-        setting = self.get_setting(key)
-        if setting is None:
-            raise TorchSdkException(f'Setting not found with name {key}')
-        payload = {}
-        url = f'{self._catalog_api_base}/setting/{setting.id}?operation=reset'
-        response = self._put(
-            url=url, payload=payload
-        )
-        return response
-
-    def update_asset_annotation(self, id: int, payload: dict):
-        if id is None:
-            raise Exception('Asset id is required')
-        url = f'{self._catalog_api_base}/assets/{id}/annotation'
-        response = self._put(
-            url=url, payload=payload
-        )
-        return response
-
-    def get_asset_activity(self, id: int):
-        if id is None:
-            raise Exception('Asset id is required')
-        url = f'{self._catalog_api_base}/assets/{id}/activity'
-        response = self._get(
-            url=url
-        )
-        return AssetActivity(**response)
-
-    def get_asset_comment(self, id: int):
-        if id is None:
-            raise Exception('Asset id is required')
-        url = f'{self._catalog_api_base}/assets/{id}/comments'
-        response = self._get(
-            url=url
-        )
-        comments = list(response['comments'])
-        comments_list = []
-        for res in comments:
-            comments_list.append(AssetComment(**res))
-        return comments_list
-
-    def get_user_by_id(self, id: int) -> User:
-        if id is None:
-            raise TorchSdkException('User id is required')
-        url = f'{self._catalog_api_base}/user/{id}'
-        response = self._get(
-            url=url
-        )
-        return User(**response)
-
-    def get_user_by_name(self, username: int) -> User:
-        if id is None:
-            raise TorchSdkException('Username is required')
-        url = f'{self._catalog_api_base}/user/byname/{username}'
-        response = self._get(
-            url=url
-        )
-        return User(**response)
-
-    def list_all_analysis_pipelines(self):
-        response = self._get(
-            url=f'{self._catalog_api_base}/analytics-pipelines'
-        )
-        keys = list(response['pipelines'])
-        keys_list = []
-        for res in keys:
-            keys_list.append(AnalyticsPipeline(**res))
-        return keys_list
-
     def get_analysis_pipeline(self, id: int) -> AnalyticsPipeline:
         response = self._get(
             url=f'{self._catalog_api_base}/analytics-pipelines/{id}'
         )
         return AnalyticsPipeline(**response['pipeline'])
 
-    def list_all_connections(self):
-        response = self._get(
-            url=f'{self._catalog_api_base}/connections'
-        )
-        connections = list(response['connections'])
-        conn_list = []
-        for res in connections:
-            conn_list.append(Connection(**res))
-        return conn_list
-
     def check_connection(self, create_connection):
         create_conn = create_connection.__dict__
         config_prop = []
@@ -1146,13 +676,6 @@ class TorchHttpClient(TorchClientInterFace, ABC):
             raise TorchSdkException(f'Error: {check_res.message}')
         return check_res
 
-    def get_connection(self, name):
-        connections = self.list_all_connections()
-        for conn in connections:
-            if name == conn.name:
-                return conn
-        raise TorchSdkException(f'No connection found with name {name}')
-
     def create_connection(self, create_connection) -> Connection:
         create_conn = create_connection.__dict__
         config_prop = []
@@ -1169,106 +692,6 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         )
         return Connection(**response['connection'])
 
-    def update_connection(self, name, update_connection) -> Connection:
-        connections = self.list_all_connections()
-        conn_id = None
-        for conn in connections:
-            if name == conn.name:
-                conn_id = conn.id
-        if conn_id is None:
-            raise TorchSdkException(f'No connection found with name {name}')
-        conn = update_connection.__dict__
-        config_prop = []
-        for cp in update_connection.properties:
-            config_prop.append(asdict(cp))
-        conn['properties'] = config_prop
-        payload = {
-            'connection': conn
-        }
-        url = f'{self._catalog_api_base}/connections/{conn_id}'
-        response = self._put_form_data(
-            url=url,
-            payload=payload
-        )
-        return Connection(**response['connection'])
-
-    def delete_connection(self, id):
-        response = self._delete(
-            url=f'{self._catalog_api_base}/connections/{id}'
-        )
-        return response
-
-    def get_all_auto_profile_configurations(self):
-        response = self._get(
-            url=f'{self._catalog_api_base}/assemblies/auto-profile-configurations'
-        )
-        configs = list(response)
-        auto_profile_list = []
-        for res in configs:
-            auto_profile_list.append(AutoProfileConfiguration(**res))
-        return auto_profile_list
-
-    def get_auto_profile_configuration(self, datasource_id: int) -> AutoProfileConfiguration:
-        response = self._get(
-            url=f'{self._catalog_api_base}/assemblies/{datasource_id}/auto-profile-configuration'
-        )
-        return AutoProfileConfiguration(**response)
-
-    def remove_auto_profile_configuration(self, datasource_id: int):
-        response = self._delete(
-            url=f'{self._catalog_api_base}/assemblies/{datasource_id}/auto-profile-configuration'
-        )
-        return response
-
-    def create_api_keys(self) -> APIKeys:
-        response = self._post(
-            url=f'{self._catalog_api_base}/key'
-        )
-        return APIKeys(**response['data'])
-
-    def get_api_keys(self):
-        response = self._get(
-            url=f'{self._catalog_api_base}/key'
-        )
-        keys = list(response['apiKeys'])
-        keys_list = []
-        for res in keys:
-            keys_list.append(APIKeys(**res))
-        return keys_list
-
-    def delete_api_key(self, access_key: str):
-        list = self.get_api_keys()
-        access_key_id = None
-        for i in list:
-            if i.accessKey == access_key:
-                access_key_id = i.id
-        if access_key_id is None:
-            raise TorchSdkException(f'Access key {access_key} not found in torch catalog.')
-        response = self._delete(
-            url=f'{self._catalog_api_base}/key/{access_key_id}'
-        )
-        return response
-
-    def get_notifications(self):
-        response = self._get(
-            url=f'{self._catalog_api_base}/notifications?page=0&size=50&sortBy=id:DESC'
-        )
-        notifications = list(response['notification'])
-        notifications_list = []
-        for res in notifications:
-            notifications_list.append(Notification(**res))
-        return notifications_list
-
-    def get_incidents(self):
-        response = self._get(
-            url=f'{self._catalog_api_base}/incidents'
-        )
-        incidents = list(response['incidents'])
-        inc_list = []
-        for res in incidents:
-            inc_list.append(Incident(**res))
-        return inc_list
-
     def enable_rule(self, rule_id) -> Rule:
         payload = {
             "enable": True
@@ -1297,7 +720,7 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         return RuleCancelResponse(**response['result'])
 
     def execute_rule(self, rule_type: PolicyType, rule_id, sync=True, incremental=False,
-                     failure_strategy: FailureStrategy = FailureStrategy.DoNotFail):
+                     failure_strategy: FailureStrategy = FailureStrategy.DoNotFail, pipeline_run_id=None):
         """
         Description:
             To execute rule synchronously and asynchronously
@@ -1309,7 +732,7 @@ class TorchHttpClient(TorchClientInterFace, ABC):
             fail at warning or never fail
         """
         rule_executor = Executor(rule_type, self, sync=sync)
-        rule_executor.execute(rule_id, incremental, failure_strategy=failure_strategy)
+        rule_executor.execute(rule_id, incremental, failure_strategy=failure_strategy, pipeline_run_id=pipeline_run_id)
         return rule_executor
 
     def get_rule_status(self, rule_type, execution_id) -> RuleExecutionStatus:
@@ -1334,20 +757,26 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         rule_executor = Executor(rule_type, self)
         return rule_executor.get_execution_result(execution_id, failure_strategy=failure_strategy)
 
-    def execute_dq_rule(self, rule_id, incremental=False) -> RuleExecution:
-        payload_temp = {"executionType": "FULL"}
+    def execute_dq_rule(self, rule_id, incremental=False, pipeline_run_id=None) -> RuleExecution:
+        payload_temp = dict()
+        payload_temp['executionType'] = "FULL"
         if incremental:
-            payload_temp = {"executionType": "INCREMENTAL"}
+            payload_temp['executionType'] = "INCREMENTAL"
+        if pipeline_run_id is not None:
+            payload_temp['pipelineRunId'] = pipeline_run_id
         response = self._post(
             url=f'{self._catalog_api_base}/rules/data-quality/{rule_id}/executions',
             payload=payload_temp
             )
         return RuleExecution(**response['execution'])
 
-    def execute_reconciliation_rule(self, rule_id, incremental=False) -> RuleExecution:
-        payload_temp = {"executionType": "FULL"}
+    def execute_reconciliation_rule(self, rule_id, incremental=False, pipeline_run_id=None) -> RuleExecution:
+        payload_temp = dict()
+        payload_temp['executionType'] = "FULL"
         if incremental:
-            payload_temp = {"executionType": "INCREMENTAL"}
+            payload_temp['executionType'] = "INCREMENTAL"
+        if pipeline_run_id is not None:
+            payload_temp['pipelineRunId'] = pipeline_run_id
         response = self._post(
             url=f'{self._catalog_api_base}/rules/reconciliation/{rule_id}/executions',
             payload=payload_temp
@@ -1401,7 +830,7 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         rule_id = identifier
         if not check_int(identifier):
             if rule_type.value == RuleType.DATA_QUALITY.value:
-                rule_res =  self.get_dq_rule(identifier)
+                rule_res = self.get_dq_rule(identifier)
             elif rule_type.value == RuleType.RECONCILIATION.value:
                 rule_res = self.get_reconciliation_rule(identifier)
             rule_id = rule_res.rule.id
