@@ -8,8 +8,24 @@ import pprint
 
 pp = pprint.PrettyPrinter(indent=4)
 
+torch_credentials = {
+    'url':  'https://acceldata.dev.10.90.3.89.nip.io',
+    'access_key':  '21DK0CVJUAE0LET',
+    'secret_key':  '1PT5E06TLCHKGELZCOEC7LLOCPYHJO'
+}
+torchClient = TorchClient(**torch_credentials)
+ds_id = torchClient.get_datasource('1', True)
+status = ds_id.get_crawler_status()
+# asset = torchClient.get_asset(4)
+# sample_data_asset = asset.sample_data()
 
-
+asset = torchClient.get_asset(4)
+start_profile_asset = asset.start_profile(ProfilingType.FULL)
+profile_status = start_profile_asset.get_status()
+if profile_status['profileRequest']['status'] == 'IN PROGRESS':
+    cancel_res = start_profile_asset.cancel()
+    assert cancel_res is not None
+exit()
 # from acceldata_sdk.torch_client import TorchClient
 #
 # torchClient = TorchClient(url="https://winterfel.qetest.acceldata.dev", access_key="S58A3VBB7L3T5PZ",
